@@ -10,9 +10,6 @@ use LWP::UserAgent;
 use URI;
 use XML::LibXML ;
 use Geo::Coder::GoogleMaps::Location;
-use Geo::Coder::GoogleMaps::Response;
-
-=encoding utf-8
 
 =head1 NAME
 
@@ -20,20 +17,14 @@ Geo::Coder::GoogleMaps - Google Maps Geocoding API
 
 =head1 VERSION
 
-Version 0.3.2
+Version 0.1
 
 =cut
 
-our $VERSION = '0.3.2';
+our $VERSION = '0.1';
 
 =head1 SYNOPSIS
 
-WARNING WARNING WARNING
-
-	There is a huge API change between version 0.2 and 0.3 ! Please see the documentation of the geocode() method !
-
-WARNING WARNING WARNING
-
 This module provide Google Maps API. Please note that this module use Tatsuhiko Miyagawa's work on Geo::Coder::Google as base (L<http://search.cpan.org/~miyagawa/>).
 
 In fact it's a fork of Mr Miyagawa's module. Geo::Coder::GoogleMaps use the default JSON data type as default output but also support XML/KML.
@@ -44,28 +35,17 @@ The direct output of the geocode() method is now a Geo::Coder::GoogleMaps::Locat
 	use Geo::Coder::GoogleMaps;
 	
 	my $gmap = Geo::Coder::GoogleMaps->new( apikey => 'abcd' , output => 'xml');
-	my $response = $gmap->geocode(location => '88 rue du chateau, 92600, Asnières sur seine, France');
-	if( $response->is_success() ){
-		my $location = $response->placemarks()->[0];
-		print $location->latitude,',',$location->longitude,"\n";
-		$location->toKML()->toString(); # is absolutly equivalent to $location->toKML(1);
-	}
+	my $location = $gmap->geocode(location => '88 rue du chateau, 92600, Asnières sur seine, France');
+	
+	print $location->latitude,',',$location->longitude,"\n";
+	
+	$location->toKML()->toString(); # is absolutly equivalent to $location->toKML(1);
+	
 
 =head1 FUNCTIONS
 
 =head2 new
 
-The object constructor it takes the following parameters :
-
-	apikey : your Google API key (only parameter mandatory).
-	ua : a LWP::UserAgent object. If not provided a new user agent is instanciates.
-	host : the google map service url (default is: maps.google.com)
-	output : the output method between xml, kml and json (csv support plan for futur release). Default is json.
-
-Example:
-
-	my $gmap = Geo::Coder::GoogleMaps->new( apikey => 'abcdef', host => 'maps.google.fr', output => 'xml');
-
 =cut
 
 
@@ -75,7 +55,7 @@ sub new {
 	my $key = delete $param{apikey}
 		or Carp::croak("Usage: new(apikey => \$apikey)");
 	
-	my $ua   = delete $param{ua}   || LWP::UserAgent->new(agent => "Mozilla/5.0 (compatible;Geo::Coder::GoogleMaps/$Geo::Coder::GoogleMaps::VERSION");
+	my $ua   = delete $param{ua}   || LWP::UserAgent->new(agent => __PACKAGE__ . "/$VERSION");
 	my $host = delete $param{host} || 'maps.google.com';
 	my $output = delete $param{output} || 'json';
 	
@@ -84,23 +64,6 @@ sub new {
 
 =head2 geocode
 
-WARNING WARNING WARNING
-
-	There is a huge API change between version 0.2 and 0.3 ! This method do not returns placemarks directly anymore !!
-
-WARNING WARNING WARNING
-
-Get a location from the Google Maps API. It return a L<Geo::Code::GoogleMaps::Response> object.
-
-	my $response = $gmap->geocode(location => '88 rue du chateau, 92600, Asnières sur seine, France');
-	print $response->placemarks()->[0]->Serialyze(1) if( $response->is_success() ) ;
-
-Please note that for the moment the geocode methode rely on JSON::Syck to parse the Google's output and ask for result in JSON format.
-
-In futur release the 'output' from the constructor will mainly be used to define the way you want this module get the data. 
-
-The dependency to L<JSON::Syck> and L<XML::LibXML> will be removed to be optionnal and dynamically load.
-
 =cut
 
 sub geocode {
@@ -121,7 +84,7 @@ sub geocode {
 	}
 	
 	my $uri = URI->new("http://$self->{host}/maps/geo");
-	$uri->query_form(q => $location, key => $self->{key},sensor => "false", output => "json");
+	$uri->query_form(q => $location, key => $self->{key});
 # 	$uri->query_form(q => $location, output => $self->{output}, key => $self->{key});
 	
 	my $res = $self->{ua}->get($uri);
@@ -136,23 +99,23 @@ sub geocode {
 	my $charset = ($ctype[1] =~ /charset=([\w\-]+)$/)[0] || "utf-8";
 	
 	my $content = Encode::decode($charset, $res->content);
-	local $JSON::Syck::ImplicitUnicode = 1;
-	my $data = JSON::Syck::Load($content);
-	
-# 	print "[Debug] JSON::Syck::Load()-ed data:\n",Data::Dumper::Dumper( $data ),"\n";
-	
-	my $response = Geo::Coder::GoogleMaps::Response->new(status_code => $data->{Status}->{code}, status_request => $data->{Status}->{request} );
-	my @placemark=();
-	foreach my $Placemark (@{$data->{Placemark}}){
-		my $loc = Geo::Coder::GoogleMaps::Location->new(output => $self->{output});
-		$loc->_setData($Placemark);
-# 		print "[Debug] JSON::Syck::Load()-ed data:\n",Data::Dumper::Dumper( $Placemark ),"\n";
-		$response->add_placemark($loc);
-		push @placemark, $loc;
-	}
-# 	print "[debug] new response object:\n",Data::Dumper::Dumper($response),"\n";
-	return $response;
-# 	wantarray ? @placemark : $placemark[0];
+# 	if ($self->{output} eq 'json'){
+		local $JSON::Syck::ImplicitUnicode = 1;
+		my $data = JSON::Syck::Load($content);
+		
+		my @placemark=();
+		foreach my $Placemark (@{$data->{Placemark}}){
+			my $loc = Geo::Coder::GoogleMaps::Location->new(output => $self->{output});
+			$loc->_setData($Placemark);
+			push @placemark, $loc;
+		}
+		wantarray ? @placemark : $placemark[0];
+# 	}
+# 	elsif ($self->{output} eq 'xml' || $self->{output} eq 'kml'){
+# 		my $parser = new XML::LibXML;
+# 		my $document = $parser->parse_string( $content );
+# # 		my ($kml) = $document->getChildren
+# 	}
 }
 
 1;
@@ -160,9 +123,7 @@ __END__
 
 =head1 AUTHOR
 
-L<Geo::Coder::Google> (the original module) is from Tatsuhiko Miyagawa.
-
-Arnaud Dupuis, C<< <a.dupuis at infinityperl.org> >>
+Arnaud DUPUIS, C<< <a.dupuis at nabladev.com> >>
 
 =head1 BUGS
 
@@ -182,17 +143,7 @@ You can also look for information at:
 
 =over 4
 
-=item * Infinity Perl: 
-
-L<http://www.infinityperl.org>
-
-=item * Google Code repository
-
-L<https://code.google.com/p/geo-coder-googlemaps/>
-
-=item * Google Maps API documentation
-
-L<http://code.google.com/apis/maps/documentation/geocoding/>
+=item * Nabla Development: http://www.nabladev.com and http://opensource.nabladev.com
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
@@ -216,7 +167,7 @@ L<http://search.cpan.org/dist/Geo-Coder-GoogleMaps>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2007-2010 Arnaud DUPUIS, all rights reserved.
+Copyright 2007 Arnaud DUPUIS and Nabla Development, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
