@@ -7,23 +7,17 @@ use Carp;
 use JSON::Syck;
 use XML::LibXML;
 
-our $VERSION='0.3.2';
-
-=encoding utf-8
-
 =head1 NAME
 
 Geo::Coder::GoogleMaps::Location - Geo::Coder::GoogleMaps' Location object
 
 =head1 VERSION
 
-Version 0.3.2 (follow L<Geo::Coder::Google> version number)
+Version 0.1
 
 =head1 SYNOPSIS
 
-Here we have the object returned by L<Geo::Coder::GoogleMaps::Response>->placemarks().
-
-This object can generate and manipulate the geocoding subset of KML 2.2 object (main change for the geocoding feature is the introduction of ExtendedData).
+Here we have the object returned by Geo::Coder::GoogleMaps->geocode()
 
 =head1 FUNCTIONS
 
@@ -36,12 +30,11 @@ The constructor can take the following arguments :
 	- LocalityName : yes! A locality name !
 	- ThoroughfareName: same thing => a string
 	- AdministrativeAreaName
-	- CountryName
 	- CountryNameCode
 	- address
 	- longitude
 	- latitude
-	- altitude (warning in Google Maps API altitude must be 0)
+	- altitude (warning in Google Map API altitude must be 0)
 
 =cut
 
@@ -65,8 +58,7 @@ sub new {
 					},
 					'AdministrativeAreaName' => delete $param{'AdministrativeAreaName'} || ''
 				},
-				'CountryNameCode' => delete $param{'CountryNameCode'} || '',
-				'CountryName' => delete $param{'CountryName'} || ''
+				'CountryNameCode' => delete $param{'CountryNameCode'} || ''
 			}
 		},
 		'address' => delete $param{'address'} || '',
@@ -152,20 +144,6 @@ sub AdministrativeAreaName {
 	return $data ? $self->{data}->{'AddressDetails'}->{'Country'}->{'AdministrativeArea'}->{'AdministrativeAreaName'}=$data : $self->{data}->{'AddressDetails'}->{'Country'}->{'AdministrativeArea'}->{'AdministrativeAreaName'} ;
 }
 
-=head2 CountryName
-
-Access the CountryName parameter.
-
-	print $location->CountryName(); # retrieve the value
-	$location->CountryName("France"); # set the value
-
-=cut
-
-sub CountryName {
-	my ($self,$data) = @_ ;
-	return $data ? $self->{data}->{'AddressDetails'}->{'Country'}->{'CountryName'}=$data : $self->{data}->{'AddressDetails'}->{'Country'}->{'CountryName'} ;
-}
-
 =head2 CountryNameCode
 
 Access the CountryNameCode parameter.
@@ -180,20 +158,6 @@ sub CountryNameCode {
 	return $data ? $self->{data}->{'AddressDetails'}->{'Country'}->{'CountryNameCode'}=$data : $self->{data}->{'AddressDetails'}->{'Country'}->{'CountryNameCode'} ;
 }
 
-=head2 Accuracy
-
-Access the Accuracy parameter.
-
-	print $location->Accuracy(); # retrieve the value
-	$location->Accuracy(8); # set the value
-
-=cut
-
-sub Accuracy {
-	my ($self,$data) = @_ ;
-	return $data ? $self->{data}->{'AddressDetails'}->{'Accuracy'}=$data : $self->{data}->{'AddressDetails'}->{'Accuracy'} ;
-}
-
 =head2 address
 
 Access the address parameter.
@@ -208,20 +172,6 @@ sub address {
 	return $data ? $self->{data}->{'address'}=$data : $self->{data}->{'address'} ;
 }
 
-=head2 id
-
-Access the id parameter.
-
-	print $location->id(); # retrieve the value
-	$location->id("point1"); # set the value
-
-=cut
-
-sub id {
-	my ($self,$data) = @_ ;
-	return $data ? $self->{data}->{'id'}=$data : $self->{data}->{'id'} ;
-}
-
 =head2 latitude
 
 Access the latitude parameter.
@@ -267,75 +217,6 @@ sub altitude {
 	return $data ? $self->{data}->{'Point'}->{'coordinates'}->[2]=$data : $self->{data}->{'Point'}->{'coordinates'}->[2] ;
 }
 
-=head2 coordinates
-
-This method is not really an accessor, it's only a getter which return longitude, latitude and altitude as a string.
-
-	print "Placemark's coordinates: ",$location->coordinates,"\n";
-
-=cut
-
-sub coordinates {
-	my $self = shift;
-	return $self->longitude().','.$self->latitude().','.$self->altitude ;
-}
-
-=head2 LLB_north
-
-Access the north parameter from the LatLonBox.
-
-	print $location->LLB_north(); # retrieve the value
-	$location->LLB_north(48.9157461); # set the value
-
-=cut
-
-sub LLB_north {
-	my ($self,$data) = @_ ;
-	return $data ? $self->{data}->{'ExtendedData'}->{'LatLonBox'}->{'north'}=$data : $self->{data}->{'ExtendedData'}->{'LatLonBox'}->{'north'} ;
-}
-
-=head2 LLB_south
-
-Access the south parameter from the LatLonBox.
-
-	print $location->LLB_south(); # retrieve the value
-	$location->LLB_south(48.9157461); # set the value
-
-=cut
-
-sub LLB_south {
-	my ($self,$data) = @_ ;
-	return $data ? $self->{data}->{'ExtendedData'}->{'LatLonBox'}->{'south'}=$data : $self->{data}->{'ExtendedData'}->{'LatLonBox'}->{'south'} ;
-}
-
-=head2 LLB_east
-
-Access the east parameter from the LatLonBox.
-
-	print $location->LLB_east(); # retrieve the value
-	$location->LLB_east(48.9157461); # set the value
-
-=cut
-
-sub LLB_east {
-	my ($self,$data) = @_ ;
-	return $data ? $self->{data}->{'ExtendedData'}->{'LatLonBox'}->{'east'}=$data : $self->{data}->{'ExtendedData'}->{'LatLonBox'}->{'east'} ;
-}
-
-=head2 LLB_west
-
-Access the west parameter from the LatLonBox.
-
-	print $location->LLB_west(); # retrieve the value
-	$location->LLB_west(48.9157461); # set the value
-
-=cut
-
-sub LLB_west {
-	my ($self,$data) = @_ ;
-	return $data ? $self->{data}->{'ExtendedData'}->{'LatLonBox'}->{'west'}=$data : $self->{data}->{'ExtendedData'}->{'LatLonBox'}->{'west'} ;
-}
-
 =head2 toJSON
 
 Return a JSON encoded object ( thanks to JSON::Syck::Dump() )
@@ -360,56 +241,57 @@ Please note that this function can take an optionnal argument (0 or 1) and if it
 =cut
 
 sub toKML {
-	sub _toKMLinternal {
-		my $self = shift;
-		my $document = shift;
-		my $xml_element = shift;
-		my $root = shift;
-		return unless($root);
-		return unless( ref($root) eq "HASH" );
-# 		print "[debug] _toKMLinternal() \$root=$root\n";
-		foreach my $key (keys(%{$root})){
-			next if($key eq "Accuracy");
-# 			print "[debug] _toKMLinternal() creating new element: $key\n";
-			my $new_element = $document->createElement($key);
-			if( $self->can($key) ){
-				if(defined($self->$key)){
-					$new_element->appendText($self->$key);
-					$xml_element->appendChild($new_element);
-				}
-			}
-			else{
-				if($key eq 'AddressDetails'){
-					$new_element->setNamespace("urn:oasis:names:tc:ciq:xsdschema:xAL:2.0", '',0);
-					$new_element->setAttribute('Accuracy',$self->Accuracy);
-				}
-				elsif( $key eq 'LatLonBox' ){
-					$new_element->setAttribute('north',$root->{$key}->{north});
-					$new_element->setAttribute('south',$root->{$key}->{south});
-					$new_element->setAttribute('east',$root->{$key}->{east});
-					$new_element->setAttribute('west',$root->{$key}->{west});
-				}
-				$xml_element->appendChild($new_element);
-				_toKMLinternal($self,$document,$new_element,$root->{$key}) unless($key eq 'LatLonBox');
-			}
-		}
-	}
-	
 	my $self = shift;
 	my $as_string = shift;
 	my $document = XML::LibXML::Document->createDocument( "1.0", "UTF-8" );
 	$document->setStandalone(1);
 	my $kml = $document->createElement('kml');
-# 	$kml->setNamespace("http://earth.google.com/kml/2.1", '',0);
-	$kml->setNamespace("http://www.opengis.net/kml/2.2", '',0);
+	$kml->setNamespace("http://earth.google.com/kml/2.1", '',0);
 	$document->setDocumentElement($kml);
 	my $placemark = $document->createElement('Placemark');
-	$placemark->setAttribute('id',$self->id);
 	$kml->appendChild($placemark);
-	my $data = {%{$self->{data}}};
-	delete($data->{id});
-# 	delete($data->{AddressDetails}->{Accuracy});
-	_toKMLinternal($self,$document,$placemark,$data);
+	my $address = $document->createElement('address');
+	$address->appendText($self->address);
+	$placemark->appendChild($address);
+	my $AddressDetails = $document->createElement('AddressDetails');
+	$placemark->appendChild($AddressDetails);
+	my $Country = $document->createElement('Country');
+	$AddressDetails->appendChild($Country);
+	my $CountryNameCode = $document->createElement('CountryNameCode');
+	$CountryNameCode->appendText($self->CountryNameCode);
+	$Country->appendChild($CountryNameCode);
+	my $AdministrativeArea = $document->createElement('AdministrativeArea');
+	$Country->appendChild($AdministrativeArea);
+	my $AdministrativeAreaName = $document->createElement('AdministrativeAreaName');
+	$AdministrativeAreaName->appendText($self->AdministrativeAreaName);
+	$AdministrativeArea->appendChild($AdministrativeAreaName);
+	my $SubAdministrativeArea = $document->createElement('SubAdministrativeArea');
+	$AdministrativeArea->appendChild($SubAdministrativeArea);
+	my $SubAdministrativeAreaName = $document->createElement('SubAdministrativeAreaName');
+	$SubAdministrativeAreaName->appendText($self->SubAdministrativeAreaName);
+	$SubAdministrativeArea->appendChild($SubAdministrativeAreaName);
+	my $Locality = $document->createElement('Locality');
+	$SubAdministrativeArea->appendChild($Locality);
+	my $LocalityName = $document->createElement('LocalityName');
+	$LocalityName->appendText($self->LocalityName);
+	$Locality->appendChild($LocalityName);
+	my $PostalCode = $document->createElement('PostalCode');
+	$Locality->appendChild($PostalCode);
+	my $PostalCodeNumber = $document->createElement('PostalCodeNumber');
+	$PostalCodeNumber->appendText($self->PostalCodeNumber);
+	$PostalCode->appendChild($PostalCodeNumber);
+	my $Thoroughfare = $document->createElement('Thoroughfare');
+	$Locality->appendChild($Thoroughfare);
+	my $ThoroughfareName = $document->createElement('ThoroughfareName');
+	$ThoroughfareName->appendText($self->ThoroughfareName);
+	$Thoroughfare->appendChild($ThoroughfareName);
+	my $Point = $document->createElement('Point');
+	$placemark->appendChild($Point);
+	my $coordinates = $document->createElement('coordinates');
+	$Point->appendChild($coordinates);
+	$coordinates->appendText($self->longitude().','.$self->latitude().','.$self->altitude);
+	
+	
 	$document->setEncoding("UTF-8");
 	return $document->toString(1) if($as_string);
 	return $document;
@@ -454,7 +336,7 @@ sub _setData {
 
 =head1 AUTHOR
 
-Arnaud Dupuis, C<< <a.dupuis at infinityperl.org> >>
+Arnaud DUPUIS, C<< <a.dupuis at nabladev.com> >>
 
 =head1 BUGS
 
@@ -468,23 +350,13 @@ your bug as I make changes.
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Geo::Coder::GoogleMaps::Location
+    perldoc Geo::Coder::GoogleMaps
 
 You can also look for information at:
 
 =over 4
 
-=item * Infinity Perl: 
-
-L<http://www.infinityperl.org>
-
-=item * Google Code repository
-
-L<https://code.google.com/p/geo-coder-googlemaps/>
-
-=item * Google Maps API documentation
-
-L<http://code.google.com/apis/maps/documentation/geocoding/>
+=item * Nabla Development: http://www.nabladev.com and http://opensource.nabladev.com
 
 =item * AnnoCPAN: Annotated CPAN documentation
 
